@@ -4,10 +4,9 @@ use strict;
 use warnings;
 use v5.10;
 use Moo;
-use warnings NONFATAL => 'all';
 
 # ABSTRACT: Fetch a tree of bugzilla bugs blocking a bug
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 has ua => (
@@ -97,13 +96,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WWW::Bugzilla::BugTree - Fetch a tree of bugzilla bugs blocking a bug
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
