@@ -4,12 +4,11 @@ use strict;
 use warnings;
 use v5.10;
 use Moo;
-use warnings NONFATAL => 'all';
 use XML::Simple qw( XMLin );
 use overload '""' => sub { shift->as_string };
 
 # ABSTRACT: A bug tree returned from WWW::Bugzilla::BugTree
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 has url => (
@@ -72,13 +71,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WWW::Bugzilla::BugTree::Bug - A bug tree returned from WWW::Bugzilla::BugTree
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
